@@ -24,7 +24,7 @@ from ..io.read_data_sensor import get_sensor_data
 from ..io.read_data_other import read_timeseries
 
 from ..io.write_data import write_ts_polar_data, write_ts_cum
-from ..io.write_data import write_ts_grid_data
+from ..io.write_data import write_ts_grid_data, write_multiple_points
 
 from ..graph.plots_timeseries import plot_timeseries, plot_timeseries_comp
 from ..graph.plots_vol import plot_cappi, plot_traj
@@ -174,6 +174,22 @@ def generate_timeseries_products(dataset, prdcfg):
     if 'prdsavedir' in prdcfg:
         prdsavedir = prdcfg['prdsavedir']
 
+    if prdcfg['type'] == 'WRITE_MULTIPLE_POINTS':
+
+        savedir = get_save_dir(
+            prdcfg['basepath'], prdcfg['procname'], dssavedir, prdsavedir,
+            timeinfo=dataset['ref_time'])
+
+        csvfname = make_filename(
+            'POI', prdcfg['dstype'], dataset['datatype'], ['csv'],
+            timeinfo=dataset['ref_time'])[0]
+
+        csvfname = savedir+csvfname
+        write_multiple_points(dataset, csvfname)
+        print('saved CSV file: '+csvfname)
+
+        return csvfname
+
     if prdcfg['type'] == 'PLOT_AND_WRITE_POINT':
         set_time_info = prdcfg.get('set_time_info', True)
         if 'antenna_coordinates_az_el_r' in dataset:
